Changelog
=========

0.6.0b6 (2025-06-17)
--------------------
- Add support for Python 3.14
- Add support for PyPy 3.11
- Drop support for Python 3.9 (due to compatibility issues).
- Drop support for PyPy 3.9
- | Drop support for Oracle Java 1.8 (jdk, jre) due to licensing issues
  | and the end of support from Oracle.
- Update readthedocs's python to version 3.13
- Update tox's base_python to version 3.13
- Added utilities: dll_path(), python_dll_path()
- pvm.h has been moved to jni (v.1.2.0b1) as pvm.c.
- Tox configuration is now in native (toml) format.
- Setup (dependencies) update.

0.6.0b5 (2024-11-08)
--------------------
- Add support for Python 3.10, 3.11, 3.12 and 3.13
- Drop support for Python 3.7 and 3.8
- Add support for PyPy 3.9 and 3.10
- pvm.h has been included for further development.
- Tox configuration has been moved to pyproject.toml
- Setup update (now based on tox >= 4.0).
- Fix the bug in lib/classproperty.
- Fixes for bugs in JVMFinder's.
- Copyright year update.
- Unittest have been performed for much more JVMs.
- Setup fixes.
- Setup (dependencies) update.

0.5.0b7 (2022-01-29)
--------------------
- Drop support for Python 3.6
- Setup update.

0.5.0b5 (2021-10-16)
--------------------
- dll_path argument of JVM() can also be type os.PathLike.
- Copyright year update.
- Setup update.

0.5.0b3 (2020-12-13)
--------------------
- Add support for Python 3.9
- General update, improvements and cleanup.
- Setup update.
- Elimination of dependence on _testcapi.

0.4.0b3 (2020-03-08)
--------------------
- Drop support for Python2
- Update of Mozilla Rhino.
- Update of license info.
- Setup update.

0.3.0b2 (2019-07-10)
--------------------
- Last release for Python2

0.3.0b1 (2018-11-08)
--------------------
- Bug fixes and improvements.
- Add Java 10 support.
- Update of the required setuptools version.
- Setup and tests improvements.

0.2.0b3 (2018-05-29)
--------------------
- Bug fixes and improvements in Java 9 support.
- Improved support for Cygwin.
- Update of Mozilla Rhino.
- Update of the required setuptools version.

0.2.0b1 (2018-02-26)
--------------------
- Improvement and simplification of setup and packaging.

0.1.1 (2005-10-05)
------------------
- Initial version.
